@@ -255,6 +255,28 @@ sub postamble {
     "\t$noecho\$(FULLPERL) inc/mm-clean.pl\n" .
     "\t$noecho\$(RM_RF) _mm ffi-probe-*\n\n";
 
+  # TODO: remove this conditional at a later date
+  if($^O =~ /bsd$/)
+  {
+    # Workaround for the tireless testers out there
+    # who want to make -jX a thing.  For some reason.
+    #
+    # When bsd make is passed -jX it turns off compat
+    # mode, even if the Makefile itself turns off
+    # parallel build.  Unfortunately the Makefile
+    # generated by EUMM does not work without compat
+    # mode.  So we:
+    $postamble .=
+      # 1. turn off parallel build using the bsd-only
+      #    faux rule `.NO_PARALLEL` rather than the
+      #    more portable `.NOTPARALLEL`, because this
+      #    will allow parallel build with gmake, which
+      #    does work.
+      ".NO_PARALLEL:\n\n" .
+      # 2. turn compat mode back on.
+      ".MAKE.MODE=compat\n\n";
+  }
+
   $postamble;
 }
 
